.. _astrodynx.events:

``astrodynx.events``
====================

.. currentmodule:: astrodynx.events

.. container:: module-header

   .. automodule:: astrodynx.events
      :no-index:

.. container:: module-content

   .. rubric:: Event Detection Functions

   .. autosummary::
      :toctree: generated/
      :template: function.rst
      :nosignatures:

      radius_islow


.. container:: module-footer

   .. rubric:: Module Information

   **Full name:** ``astrodynx.events``

   **Source:** `View source on GitHub <https://github.com/adxorg/astrodynx/blob/main/src/astrodynx/events>`_
